@@ -10,8 +10,7 @@ from .common import parcel_weight
 __all__ = ['Sale']
 
 
-class Sale:
-    __metaclass__ = PoolMeta
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
 
     def _group_parcel_key(self, lines, line):
@@ -29,7 +28,7 @@ class Sale:
         weights = []
         context['weights'] = weights
 
-        lines = self.lines or []
+        lines = [l for l in self.lines or [] if l.quantity > 0]
         keyfunc = partial(self._group_parcel_key, lines)
         lines = sorted(lines, key=keyfunc)
 
